pub enum WebRouteError {
InvalidValue,
UnpopulatedParam(String),
}Variants
InvalidValue
When generating a populated route, the values input needs to
serialize into key-value pairs.
UnpopulatedParam(String)
When generating a populated route, there was no value to populate the specified parameter key.