Struct ParameterizedRoute

pub struct ParameterizedRoute { /* private fields */ }
Defines a route structure that can be used to define routes for a webserver.

Its templated sections can be easily populated to create a WebRoute which can be used to make requests against the webserver routes that the ParameterizedRoute was used to define.

Implementations

Source

impl ParameterizedRoute

pub fn new<R: ToParameterizedSegments>(route: R) -> Self

Creates a new ParameterizedRoute.

Examples
use web_route::ParameterizedRoute;

let route = ParameterizedRoute::new("/some/route/{param}");
pub fn join<R: ToParameterizedSegments>(&self, route: R) -> Self

Joins a route onto an existing ParameterizedRoute returning the joined route.

Examples
use web_route::ParameterizedRoute;

let route = ParameterizedRoute::new("/some/route/{param}");
let nested_route = ParameterizedRoute::new("/a/nested/route");
let joined_route = route.join(&nested_route);

assert_eq!(joined_route, route.join("/a/nested/route"))
pub fn to_web_route<V: Serialize>( &self, values: &V, ) -> Result<WebRoute, WebRouteError>

Attempts to populate the parameters of the route with their values and returns a WebRoute.

values needs to implement serde::Serialize and be of an “Object” style (with key-value pairs).

This would be used when making a request to an endpoint represented by the route.

Errors
Examples
use web_route::ParameterizedRoute;

#[derive(serde::Serialize)]
struct RouteParams {
    param: String,
}

let parameterized_route = ParameterizedRoute::new("/some/route/{param}");
let web_route = parameterized_route
    .to_web_route(&RouteParams {
        param: "value".to_owned(),
    })
    .unwrap();
     
assert_eq!(&web_route.to_string(), "/some/route/value")