Struct WebRoute

pub struct WebRoute { /* private fields */ }

Implementations

Source

impl WebRoute

pub fn new<R: ToSegments>(route: R) -> Self

Creates a new WebRoute.

Examples
use web_route::WebRoute;

let route = WebRoute::new("/some/route/{param}");
pub fn join<R: ToSegments>(&self, route: R) -> Self

Joins a route onto an existing WebRoute returning the joined route.

Examples
use web_route::WebRoute;

let route = WebRoute::new("/some/route/{param}");
let nested_route = WebRoute::new("/a/nested/route");
let joined_route = route.join(&nested_route);

assert_eq!(joined_route, route.join("/a/nested/route"))
pub fn as_template_route(&self) -> String

Returns the route in its “templated” representation so that it can be used in web server route definitions.

Examples
use web_route::WebRoute;

let route = WebRoute::new("/some/route/{param}");
let template_route = route.as_template_route();

assert_eq!(template_route, "/some/route/{param}")
pub fn as_populated_route<V: Serialize>( &self, values: &V, ) -> Result<String, WebRouteError>

Attempts to populate the parameters of the route with their values.

values needs to implement serde::Serialize and be of an “Object” style (with key-value pairs).

This would be used when making a request to an endpoint represented by the route.

Errors
Examples
use web_route::WebRoute;

#[derive(serde::Serialize)]
struct RouteParams {
    param: String,
}

let route = WebRoute::new("/some/route/{param}");
let populated_route = route
    .as_populated_route(&RouteParams {
        param: "value".to_owned(),
    })
    .unwrap();
     
assert_eq!(populated_route, "/some/route/value")